animator.display.display.DM_html

class animator.display.display.DM_html(*args: Any, **kwargs: Any)

Bases: animator.display.DisplayManager.DisplayManager

__init__(*args: Any, **kwargs: Any) → None

Manages the display of a scene.

Parameters
  • scene – The scene to display.

  • delay – The delay between frames. If None, the delay will be calculated from the scene’s fps.

Methods

__init__(*args, **kwargs)

Manages the display of a scene.

close()

Closes the DisplayManager.

frame_b64()

get_best()

Returns the best available DisplayManager.

show_frame()

Displays the current frame and returns True.

waittime()

Returns the time to wait until the next frame should be displayed in seconds.

Attributes

display_method

close() → None

Closes the DisplayManager.

classmethod get_best() → Type[animator.display.DisplayManager.DisplayManager]

Returns the best available DisplayManager.

show_frame() → bool

Displays the current frame and returns True. If the window was closed, returns False.

waittime() → float

Returns the time to wait until the next frame should be displayed in seconds. This will be at least 0.001 seconds.