animator.display.display.DM_qt

class animator.display.display.DM_qt(*args: Any, **kwargs: Any)

Bases: animator.display.DisplayManager.DisplayManager

__init__(*args: Any, **kwargs: Any) → None

Manages the display of a scene.

Parameters
  • scene – The scene to display.

  • delay – The delay between frames. If None, the delay will be calculated from the scene’s fps.

Methods

__init__(*args, **kwargs)

Manages the display of a scene.

close()

Closes the DisplayManager.

get_best()

Returns the best available DisplayManager.

show_frame()

Displays the current frame and returns True.

waittime()

Returns the time to wait until the next frame should be displayed in seconds.

Attributes

display_method

class Window(manager: animator.display.display.DM_qt)

Bases: PyQt5.QtWidgets.QMainWindow

class DockOption

Bases: int

class DockOptions
class DockOptions(Union[QMainWindow.DockOptions, QMainWindow.DockOption]) → None
class DockOptions(QMainWindow.DockOptions) → None

Bases: sip.simplewrapper

class PaintDeviceMetric

Bases: int

class RenderFlag

Bases: int

class RenderFlags
class RenderFlags(Union[QWidget.RenderFlags, QWidget.RenderFlag]) → None
class RenderFlags(QWidget.RenderFlags) → None

Bases: sip.simplewrapper

acceptDrops(self) → bool
accessibleDescription(self) → str
accessibleName(self) → str
actionEvent(self, QActionEvent)
actions(self) → List[QAction]
activateWindow(self)
addAction(self, QAction)
addActions(self, Iterable[QAction])
addDockWidget(self, Qt.DockWidgetArea, QDockWidget)
addDockWidget(self, Qt.DockWidgetArea, QDockWidget, Qt.Orientation) → None
addToolBar(self, Qt.ToolBarArea, QToolBar)
addToolBar(self, QToolBar) → None
addToolBar(self, str) → QToolBar
addToolBarBreak(self, area: Qt.ToolBarArea = Qt.TopToolBarArea)
adjustSize(self)
autoFillBackground(self) → bool
backgroundRole(self) → QPalette.ColorRole
baseSize(self) → QSize
blockSignals(self, bool) → bool
centralWidget(self) → QWidget
changeEvent(self, QEvent)
childAt(self, QPoint) → QWidget
DM_qt.Window.childAt(self, int, int) -> QWidget
childEvent(self, QChildEvent)
children(self) → List[QObject]
childrenRect(self) → QRect
childrenRegion(self) → QRegion
clearFocus(self)
clearMask(self)
close(self) → bool
closeEvent(self, QCloseEvent)
colorCount(self) → int
connectNotify(self, QMetaMethod)
contentsMargins(self) → QMargins
contentsRect(self) → QRect
contextMenuEvent(self, QContextMenuEvent)
contextMenuPolicy(self) → Qt.ContextMenuPolicy
corner(self, Qt.Corner) → Qt.DockWidgetArea
create(self, window: PyQt5.sip.voidptr = 0, initializeWindow: bool = True, destroyOldWindow: bool = True)
createPopupMenu(self) → QMenu
createWindowContainer(QWindow, parent: QWidget = None, flags: Union[Qt.WindowFlags, Qt.WindowType] = 0) → QWidget
cursor(self) → QCursor
customEvent(self, QEvent)
deleteLater(self)
depth(self) → int
destroy(self, destroyWindow: bool = True, destroySubWindows: bool = True)
devType(self) → int
devicePixelRatio(self) → int
devicePixelRatioF(self) → float
devicePixelRatioFScale() → float
disconnect(QMetaObject.Connection) → bool
disconnect(self) → None
disconnectNotify(self, QMetaMethod)
dockOptions(self) → QMainWindow.DockOptions
dockWidgetArea(self, QDockWidget) → Qt.DockWidgetArea
documentMode(self) → bool
dragEnterEvent(self, QDragEnterEvent)
dragLeaveEvent(self, QDragLeaveEvent)
dragMoveEvent(self, QDragMoveEvent)
dropEvent(self, QDropEvent)
dumpObjectInfo(self)
dumpObjectTree(self)
dynamicPropertyNames(self) → List[QByteArray]
effectiveWinId(self) → PyQt5.sip.voidptr
ensurePolished(self)
enterEvent(self, QEvent)
event(self, QEvent) → bool
eventFilter(self, QObject, QEvent) → bool
find(PyQt5.sip.voidptr) → QWidget
findChild(self, type, name: str = '', options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → QObject
findChild(self, Tuple, name: str = '', options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → QObject
findChildren(self, type, name: str = '', options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → List[QObject]
findChildren(self, Tuple, name: str = '', options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → List[QObject]
findChildren(self, type, QRegExp, options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → List[QObject]
findChildren(self, Tuple, QRegExp, options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → List[QObject]
findChildren(self, type, QRegularExpression, options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → List[QObject]
findChildren(self, Tuple, QRegularExpression, options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) → List[QObject]
focusInEvent(self, QFocusEvent)
focusNextChild(self) → bool
focusNextPrevChild(self, bool) → bool
focusOutEvent(self, QFocusEvent)
focusPolicy(self) → Qt.FocusPolicy
focusPreviousChild(self) → bool
focusProxy(self) → QWidget
focusWidget(self) → QWidget
font(self) → QFont
fontInfo(self) → QFontInfo
fontMetrics(self) → QFontMetrics
foregroundRole(self) → QPalette.ColorRole
frameGeometry(self) → QRect
frameSize(self) → QSize
geometry(self) → QRect
getContentsMargins(self) → Tuple[int, int, int, int]
grab(self, rectangle: QRect = QRect(QPoint(0, 0), QSize(- 1, - 1))) → QPixmap
grabGesture(self, Qt.GestureType, flags: Union[Qt.GestureFlags, Qt.GestureFlag] = Qt.GestureFlags())
grabKeyboard(self)
grabMouse(self)
grabMouse(self, Union[QCursor, Qt.CursorShape]) → None
grabShortcut(self, Union[QKeySequence, QKeySequence.StandardKey, str, int], context: Qt.ShortcutContext = Qt.WindowShortcut) → int
graphicsEffect(self) → QGraphicsEffect
graphicsProxyWidget(self) → QGraphicsProxyWidget
hasFocus(self) → bool
hasHeightForWidth(self) → bool
hasMouseTracking(self) → bool
hasTabletTracking(self) → bool
height(self) → int
heightForWidth(self, int) → int
heightMM(self) → int
hide(self)
hideEvent(self, QHideEvent)
iconSize(self) → QSize
inherits(self, str) → bool
initPainter(self, QPainter)
inputMethodEvent(self, QInputMethodEvent)
inputMethodHints(self) → Qt.InputMethodHints
inputMethodQuery(self, Qt.InputMethodQuery) → Any
DM_qt.Window.insertAction(self, QAction, QAction)
insertActions(self, QAction, Iterable[QAction])
DM_qt.Window.insertToolBar(self, QToolBar, QToolBar)
insertToolBarBreak(self, QToolBar)
installEventFilter(self, QObject)
isActiveWindow(self) → bool
isAncestorOf(self, QWidget) → bool
isAnimated(self) → bool
isDockNestingEnabled(self) → bool
isEnabled(self) → bool
isEnabledTo(self, QWidget) → bool
isFullScreen(self) → bool
isHidden(self) → bool
isLeftToRight(self) → bool
isMaximized(self) → bool
isMinimized(self) → bool
isModal(self) → bool
isRightToLeft(self) → bool
isSeparator(self, QPoint) → bool
isSignalConnected(self, QMetaMethod) → bool
isVisible(self) → bool
isVisibleTo(self, QWidget) → bool
isWidgetType(self) → bool
isWindow(self) → bool
isWindowModified(self) → bool
isWindowType(self) → bool
keyPressEvent(self, QKeyEvent)
keyReleaseEvent(self, QKeyEvent)
keyboardGrabber() → QWidget
killTimer(self, int)
layout(self) → QLayout
layoutDirection(self) → Qt.LayoutDirection
leaveEvent(self, QEvent)
locale(self) → QLocale
logicalDpiX(self) → int
logicalDpiY(self) → int
lower(self)
mapFrom(self, QWidget, QPoint) → QPoint
mapFromGlobal(self, QPoint) → QPoint
mapFromParent(self, QPoint) → QPoint
mapTo(self, QWidget, QPoint) → QPoint
mapToGlobal(self, QPoint) → QPoint
mapToParent(self, QPoint) → QPoint
mask(self) → QRegion
maximumHeight(self) → int
maximumSize(self) → QSize
maximumWidth(self) → int
menuBar(self) → QMenuBar
menuWidget(self) → QWidget
metaObject(self) → QMetaObject
metric(self, QPaintDevice.PaintDeviceMetric) → int
minimumHeight(self) → int
minimumSize(self) → QSize
minimumSizeHint(self) → QSize
minimumWidth(self) → int
mouseDoubleClickEvent(self, QMouseEvent)
mouseGrabber() → QWidget
mouseMoveEvent(self, QMouseEvent)
mousePressEvent(self, QMouseEvent)
mouseReleaseEvent(self, QMouseEvent)
move(self, QPoint)
DM_qt.Window.move(self, int, int) -> None
moveEvent(self, QMoveEvent)
moveToThread(self, QThread)
nativeEvent(self, Union[QByteArray, bytes, bytearray], PyQt5.sip.voidptr) → Tuple[bool, int]
nativeParentWidget(self) → QWidget
nextInFocusChain(self) → QWidget
normalGeometry(self) → QRect
objectName(self) → str
overrideWindowFlags(self, Union[Qt.WindowFlags, Qt.WindowType])
overrideWindowState(self, Union[Qt.WindowStates, Qt.WindowState])
paintEngine(self) → QPaintEngine
paintEvent(self, QPaintEvent)
paintingActive(self) → bool
palette(self) → QPalette
parent(self) → QObject
parentWidget(self) → QWidget
physicalDpiX(self) → int
physicalDpiY(self) → int
pos(self) → QPoint
previousInFocusChain(self) → QWidget
property(self, str) → Any
pyqtConfigure(...)

Each keyword argument is either the name of a Qt property or a Qt signal. For properties the property is set to the given value which should be of an appropriate type. For signals the signal is connected to the given value which should be a callable.

raise_(self)
receivers(self, PYQT_SIGNAL) → int
rect(self) → QRect
releaseKeyboard(self)
releaseMouse(self)
releaseShortcut(self, int)
removeAction(self, QAction)
removeDockWidget(self, QDockWidget)
removeEventFilter(self, QObject)
removeToolBar(self, QToolBar)
removeToolBarBreak(self, QToolBar)
render(self, QPaintDevice, targetOffset: QPoint = QPoint(), sourceRegion: QRegion = QRegion(), flags: Union[QWidget.RenderFlags, QWidget.RenderFlag] = QWidget.RenderFlags(QWidget.RenderFlag.DrawWindowBackground | QWidget.RenderFlag.DrawChildren))
render(self, QPainter, targetOffset: QPoint = QPoint(), sourceRegion: QRegion = QRegion(), flags: Union[QWidget.RenderFlags, QWidget.RenderFlag] = QWidget.RenderFlags(QWidget.RenderFlag.DrawWindowBackground | QWidget.RenderFlag.DrawChildren)) → None
repaint(self)
DM_qt.Window.repaint(self, int, int, int, int) -> None
repaint(self, QRect) → None
repaint(self, QRegion) → None
resize(self, QSize)
DM_qt.Window.resize(self, int, int) -> None
resizeDocks(self, Iterable[QDockWidget], Iterable[int], Qt.Orientation)
resizeEvent(self, QResizeEvent)
restoreDockWidget(self, QDockWidget) → bool
restoreGeometry(self, Union[QByteArray, bytes, bytearray]) → bool
restoreState(self, Union[QByteArray, bytes, bytearray], version: int = 0) → bool
saveGeometry(self) → QByteArray
saveState(self, version: int = 0) → QByteArray
screen(self) → QScreen
DM_qt.Window.scroll(self, int, int)
DM_qt.Window.scroll(self, int, int, QRect) -> None
sender(self) → QObject
senderSignalIndex(self) → int
setAcceptDrops(self, bool)
setAccessibleDescription(self, str)
setAccessibleName(self, str)
setAnimated(self, bool)
setAttribute(self, Qt.WidgetAttribute, on: bool = True)
setAutoFillBackground(self, bool)
setBackgroundRole(self, QPalette.ColorRole)
DM_qt.Window.setBaseSize(self, int, int)
setBaseSize(self, QSize) → None
setCentralWidget(self, QWidget)
DM_qt.Window.setContentsMargins(self, int, int, int, int)
setContentsMargins(self, QMargins) → None
setContextMenuPolicy(self, Qt.ContextMenuPolicy)
setCorner(self, Qt.Corner, Qt.DockWidgetArea)
setCursor(self, Union[QCursor, Qt.CursorShape])
setDisabled(self, bool)
setDockNestingEnabled(self, bool)
setDockOptions(self, Union[QMainWindow.DockOptions, QMainWindow.DockOption])
setDocumentMode(self, bool)
setEnabled(self, bool)
setFixedHeight(self, int)
setFixedSize(self, QSize)
DM_qt.Window.setFixedSize(self, int, int) -> None
setFixedWidth(self, int)
setFocus(self)
setFocus(self, Qt.FocusReason) → None
setFocusPolicy(self, Qt.FocusPolicy)
setFocusProxy(self, QWidget)
setFont(self, QFont)
setForegroundRole(self, QPalette.ColorRole)
setGeometry(self, QRect)
DM_qt.Window.setGeometry(self, int, int, int, int) -> None
setGraphicsEffect(self, QGraphicsEffect)
setHidden(self, bool)
setIconSize(self, QSize)
setInputMethodHints(self, Union[Qt.InputMethodHints, Qt.InputMethodHint])
setLayout(self, QLayout)
setLayoutDirection(self, Qt.LayoutDirection)
setLocale(self, QLocale)
setMask(self, QBitmap)
setMask(self, QRegion) → None
setMaximumHeight(self, int)
DM_qt.Window.setMaximumSize(self, int, int)
setMaximumSize(self, QSize) → None
setMaximumWidth(self, int)
setMenuBar(self, QMenuBar)
setMenuWidget(self, QWidget)
setMinimumHeight(self, int)
DM_qt.Window.setMinimumSize(self, int, int)
setMinimumSize(self, QSize) → None
setMinimumWidth(self, int)
setMouseTracking(self, bool)
setObjectName(self, str)
setPalette(self, QPalette)
setParent(self, QWidget)
setParent(self, QWidget, Union[Qt.WindowFlags, Qt.WindowType]) → None
setProperty(self, str, Any) → bool
setShortcutAutoRepeat(self, int, enabled: bool = True)
setShortcutEnabled(self, int, enabled: bool = True)
DM_qt.Window.setSizeIncrement(self, int, int)
setSizeIncrement(self, QSize) → None
setSizePolicy(self, QSizePolicy)
setSizePolicy(self, QSizePolicy.Policy, QSizePolicy.Policy) → None
setStatusBar(self, QStatusBar)
setStatusTip(self, str)
setStyle(self, QStyle)
setStyleSheet(self, str)
DM_qt.Window.setTabOrder(QWidget, QWidget)
setTabPosition(self, Union[Qt.DockWidgetAreas, Qt.DockWidgetArea], QTabWidget.TabPosition)
setTabShape(self, QTabWidget.TabShape)
setTabletTracking(self, bool)
setToolButtonStyle(self, Qt.ToolButtonStyle)
setToolTip(self, str)
setToolTipDuration(self, int)
setUnifiedTitleAndToolBarOnMac(self, bool)
setUpdatesEnabled(self, bool)
setVisible(self, bool)
setWhatsThis(self, str)
setWindowFilePath(self, str)
setWindowFlag(self, Qt.WindowType, on: bool = True)
setWindowFlags(self, Union[Qt.WindowFlags, Qt.WindowType])
setWindowIcon(self, QIcon)
setWindowIconText(self, str)
setWindowModality(self, Qt.WindowModality)
setWindowModified(self, bool)
setWindowOpacity(self, float)
setWindowRole(self, str)
setWindowState(self, Union[Qt.WindowStates, Qt.WindowState])
setWindowTitle(self, str)
sharedPainter(self) → QPainter
show(self)
showEvent(self, QShowEvent)
showFullScreen(self)
showMaximized(self)
showMinimized(self)
showNormal(self)
signalsBlocked(self) → bool
size(self) → QSize
sizeHint(self) → QSize
sizeIncrement(self) → QSize
sizePolicy(self) → QSizePolicy
splitDockWidget(self, QDockWidget, QDockWidget, Qt.Orientation)
stackUnder(self, QWidget)
startTimer(self, int, timerType: Qt.TimerType = Qt.CoarseTimer) → int
statusBar(self) → QStatusBar
statusTip(self) → str
style(self) → QStyle
styleSheet(self) → str
tabPosition(self, Qt.DockWidgetArea) → QTabWidget.TabPosition
tabShape(self) → QTabWidget.TabShape
tabifiedDockWidgets(self, QDockWidget) → List[QDockWidget]
DM_qt.Window.tabifyDockWidget(self, QDockWidget, QDockWidget)
tabletEvent(self, QTabletEvent)
takeCentralWidget(self) → QWidget
testAttribute(self, Qt.WidgetAttribute) → bool
thread(self) → QThread
timerEvent(self, QTimerEvent)
toolBarArea(self, QToolBar) → Qt.ToolBarArea
toolBarBreak(self, QToolBar) → bool
toolButtonStyle(self) → Qt.ToolButtonStyle
toolTip(self) → str
toolTipDuration(self) → int
tr(self, str, disambiguation: str = None, n: int = - 1) → str
underMouse(self) → bool
ungrabGesture(self, Qt.GestureType)
unifiedTitleAndToolBarOnMac(self) → bool
unsetCursor(self)
unsetLayoutDirection(self)
unsetLocale(self)
update(self)
update(self, QRect) → None
update(self, QRegion) → None
DM_qt.Window.update(self, int, int, int, int) -> None
updateGeometry(self)
updateMicroFocus(self)
updatesEnabled(self) → bool
visibleRegion(self) → QRegion
whatsThis(self) → str
wheelEvent(self, QWheelEvent)
width(self) → int
widthMM(self) → int
winId(self) → PyQt5.sip.voidptr
window(self) → QWidget
windowFilePath(self) → str
windowFlags(self) → Qt.WindowFlags
windowHandle(self) → QWindow
windowIcon(self) → QIcon
windowIconText(self) → str
windowModality(self) → Qt.WindowModality
windowOpacity(self) → float
windowRole(self) → str
windowState(self) → Qt.WindowStates
windowTitle(self) → str
windowType(self) → Qt.WindowType
x(self) → int
y(self) → int
close() → None

Closes the DisplayManager.

classmethod get_best() → Type[animator.display.DisplayManager.DisplayManager]

Returns the best available DisplayManager.

show_frame() → bool

Displays the current frame and returns True. If the window was closed, returns False.

waittime() → float

Returns the time to wait until the next frame should be displayed in seconds. This will be at least 0.001 seconds.